function [xi1, xi2, wxi] = padpts3(n)
% [xi1, xi2, wxi] = padpts3(n)
%
% Builds third family Padua points of n-th degree.
%
% n      = the degree of the Padua points. Must be a positive integer.
%
% xi1    = the x values of Padua points.
% xi2    = the y values of Padua points.
% wxi    = the weights associated to each Padua point.
z = -cos([0:n] * pi / n);
zz = -cos([0:n+1] * pi / (n + 1));
[xpd1,ypd1] = meshgrid(z(1:2:n+1),zz(2:2:n+2));
xi1 = reshape(xpd1,1,size(xpd1,1) * size(xpd1,2));
xi2 = reshape(ypd1,1,size(ypd1,1) * size(ypd1,2));
[xpd2,ypd2]=meshgrid(z(2:2:n+1),zz(1:2:n+2));
xi1 = [xi1 reshape(xpd2,1,size(xpd2,1) * size(xpd2,2))];
xi2 = [xi2 reshape(ypd2,1,size(ypd2,1) * size(ypd2,2))];
% weights
if (mod(n,2))
  n1 = (n + 1) / 2;
  wxi = ones(1,n1);
  wxi = [wxi repmat(2,1,n1 * (n1 - 1))];
  wxi = [wxi repmat([1 repmat(2,1,n1 - 1) 1],1,n1 - 1)];
  wxi = [wxi 0.5 repmat(1,1,n1 - 1) 0.5];
else
  n1 = (n + 2) / 2;
  wxi = [ones(1,n1 - 1) 0.5];
  wxi = [wxi repmat([repmat(2,1,n1 - 1) 1],1,n1 - 2)];
  wxi = [wxi ones(1,n1 - 1) 0.5];
  wxi = [wxi repmat([1 repmat(2,1,n1 - 1)],1,n1 - 1)];
end
wxi = wxi / (n * (n + 1));
