function [xi1, xi2, wxi] = xupts1(n)
% [xi1, xi2, wxi] = xupts1(n, vertex)
%
% Builds Xu points of n-th (even) degree with vertices 
% on topright and bottomleft
%
% n      = the degree of the Xu points. Must be a positive integer.
%
% xi1    = the x values of Xu points.
% xi2    = the y values of Xu points.
% wxi    = the weights associated to each Xu point.
z = cos([0:n] * pi / n);
[xu1,yu1] = meshgrid(z(1:2:n+1),z(1:2:n+1));
[xu2,yu2] = meshgrid(z(2:2:n+1),z(2:2:n+1));
xi1 = [reshape(xu1,1,((n + 1) / 2) ^ 2) reshape(xu2,1,((n + 1) / 2) ^ 2)];
xi2 = [reshape(yu1,1,((n + 1) / 2) ^ 2) reshape(yu2,1,((n + 1) / 2) ^ 2)];
n1 = (n + 1) / 2;
wxi = [0.5 ones(1,n1 - 1)];
wxi = [wxi repmat([1 repmat(2,1,n1 - 1)],1,n1 - 1)];
wxi = [wxi repmat([repmat(2,1,n1 - 1) 1],1,n1 - 1)];
wxi = [wxi ones(1,n1 - 1) 0.5];
wxi = wxi / n ^ 2;
